
WuttaTell
=========

This package adds simple telemetry submission features for the Wutta Framework.

Good documentation and 100% `test coverage`_ are priorities for this
project.

.. _test coverage: https://buildbot.wuttaproject.org/coverage/wuttatell/


.. toctree::
   :maxdepth: 2
   :caption: Documentation

   narr/install
   narr/cli/index

.. toctree::
   :maxdepth: 1
   :caption: API

   api/wuttatell
   api/wuttatell.app
   api/wuttatell.cli
   api/wuttatell.cli.tell
   api/wuttatell.client
   api/wuttatell.telemetry
